#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hostname
version:              1.0
visibility:           public
id:                   hostname-1.0-B6rimLIP2kIHedZYMVt5f8
key:                  hostname-1.0-B6rimLIP2kIHedZYMVt5f8
license:              BSD-3-Clause
maintainer:           Max Bolingbroke <batterseapower@hotmail.com>
author:               Max Bolingbroke <batterseapower@hotmail.com>
synopsis:
    A very simple package providing a cross-platform means of determining the hostname

category:             Network
abi:                  e6da43898a51f6cdc1e2aa586fae619b
exposed:              True
exposed-modules:      Network.HostName
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hostname-1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hostname-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hostname-1.0
hs-libraries:         HShostname-1.0-B6rimLIP2kIHedZYMVt5f8
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-hostname/html/hostname.haddock
haddock-html:         /usr/share/doc/haskell-hostname/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

